@@ -1,8 +1,9 @@
 idc <- 
 function(y, x, z, P, G, to) {
+  from <- NULL
   G.xz <- unobserved.graph(G)
-  edges.to.x <- E(G.xz) [1:length(E(G.xz)) %->% x]
-  edges.from.z <- E(G.xz) [1:length(E(G.xz)) %<-% z]
+  edges.to.x <- E(G.xz)[to(x)]
+  edges.from.z <- E(G.xz)[from(z)]
   G.xz <- subgraph.edges(G.xz, E(G.xz)[setdiff(E(G.xz), union(edges.to.x, edges.from.z))], delete.vertices = FALSE)
   A <- as.matrix(get.adjacency(G.xz))
   for (node in z) {
