@@ -9,7 +9,7 @@ function(G) {
     e <- get.edges(G, unobs.edges)
     for (i in 1:u) G <- G + edges(c(new.nodes[i], v[e[i,1]]), c(new.nodes[i], v[e[i,2]]))
     unobs.edges <- which(edge.attributes(G)$description == "U")
-    obs.edges <- setdiff(1:length(E(G)), unobs.edges)
+    obs.edges <- setdiff(E(G), E(G)[which(edge.attributes(G)$description == "U")])
     G.unobs <- subgraph.edges(G, E(G)[obs.edges], delete.vertices = FALSE)
     return(G.unobs)
   }
